@@ -30,6 +30,7 @@ from zope import component
 gsm = component.getGlobalSiteManager()
 
 gsm.registerAdapter(NetworksSetup2TermSet)
+gsm.registerAdapter(NetworksSetupClampings2TermSet)
 gsm.registerAdapter(PotasscoDesigner)
 gsm.registerAdapter(ClampingList2CsvWriter)
 
@@ -40,5 +41,7 @@ reg.register('caspo.design.opt', os.path.join(root, 'encodings/gringo4/idesign.l
 reg = component.getUtility(asp.IArgumentRegistry)
 reg.register('caspo.design.opt', ['-c maxstimuli={stimuli}', 
                                   '-c maxinhibitors={inhibitors}', 
-                                  '-c imax={imax}'],                                  potassco.IGringoGrounder)
+                                  '-c imax={imax}',
+                                  '-c relax={relax}',
+                                  '-c iquery={iquery}'],                              potassco.IGringoGrounder)
 reg.register('caspo.design.opt', ["--quiet=1", "--opt-mode=optN", "--save-progress"], potassco.IClasp3)
